Struct PortCollection

pub(crate) struct PortCollection {
    name: CapeStringImpl,
    description: CapeStringImpl,
    ports: Vec<CapeUnitPort>,
    shared_unit_data: Rc<RefCell<SharedUnitData>>,
    cobia_object_data: PortCollectionCobiaObjectData,
}
The PortCollection class implements a CAPE-OPEN 1.2 collection of unit ports for the DistillationShortcutUnit.

It provides methods to manage and access the ports associated with the unit.

Fields

name: CapeStringImpl

The name of the port collection

description: CapeStringImpl

The description of the port collection

ports: Vec<CapeUnitPort>

The ports contained in this collection

shared_unit_data: Rc<RefCell<SharedUnitData>>

Shared data for the unit, allowing access to common properties.

cobia_object_data: PortCollectionCobiaObjectData

Cobia object data for this object, which contains generated code to provide the native COBIA interfaces

Implementations

Source

impl PortCollection

fn create_instance( _port_collection_boxed_ptr: *mut *mut ICapeInterface, shared_unit_data: Rc<RefCell<SharedUnitData>>, ) -> CapeResult

pub(crate) fn create<T: CapeSmartPointer>( shared_unit_data: Rc<RefCell<SharedUnitData>>, ) -> T

Create a new instance of the object and return a smart pointer to it

This function panics if the created object does not implement the interface corresponding to the smart pointer to be returned. For a non-panic version, use the try_create() function.

pub(crate) fn try_create<T: CapeSmartPointer>( shared_unit_data: Rc<RefCell<SharedUnitData>>, ) -> Result<T, COBIAError>

Create a new instance of the object and return a smart pointer to it

This function returns an error if the created object does not implement the interface corresponding to the smart pointer to be returned.

pub(crate) unsafe fn borrow<T: CapeSmartPointer>(smart_pointer: &T) -> &Self

Get a reference to the object

Note that as the reference is created from a smart pointer, the reference is valid only as long as the smart pointer is valid. The reference is not checked for multiple borrows

Safety

The user must ensure that the smart pointer contains a valid object, and that the object is of the type that is being borrowed. It is not possible for the compiler to check this, as the borrow is done through the native object pointer in the interface.

pub(crate) unsafe fn borrow_mut<T: CapeSmartPointer>( smart_pointer: &mut T, ) -> &mut Self

Get a mutable reference to the object

Note that as the reference is created from a smart pointer, the reference is valid only as long as the smart pointer is valid. The reference is not checked for multiple borrows

Safety

This function is unsafe because it allows mutable access to the object. Also the user must ensure that the smart pointer contains a valid object, and that the object is of the type that is being borrowed. It is not possible for the compiler to check this, as the borrow is done through the native object pointer in the interface.

Source

impl PortCollection

fn new(shared_unit_data: Rc<RefCell<SharedUnitData>>) -> Self

Creates a new PortCollection for the distillation shortcut unit.

Arguments
  • shared_unit_data - A reference to shared data for the unit, which contains common properties.
Returns

A new instance of PortCollection initialized with the provided shared data.

pub(crate) fn add_port(&mut self, port: CapeUnitPort)

Adds a port to the collection.

Arguments
  • port - The port to be added to the collection.
pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut CapeUnitPort>

Obtain an iterator to iterate over the ports in the collection.

Returns

An iterator that yields references to the ports in the collection.